NZB Clients
===========
[![Build Status](https://travis-ci.org/jblakeney/nzbclients.svg?branch=master)](https://travis-ci.org/jblakeney/nzbclients)

A collection of unofficial client libraries for interacting with programs that download NZB files.

Supported clients so far are:
- Sonarr
- Radarr
- SABnzbd (coming soon)

Feel free to open an issue with any suggestions on further clients to support

Requirements
============

- Python >= 3.6

License
=======

MIT licensed. See the bundled `LICENSE <https://github.com/jblakeney/nzbclients/blob/master/LICENSE>`_ file for more details.
